@@ -1,6 +1,7 @@
 use swc_common::util::take::Take;
 use swc_ecma_ast::*;
-use swc_ecma_transforms_base::ext::PatOrExprExt;
+use swc_ecma_transforms_base::{ext::PatOrExprExt, perf::Parallel};
+use swc_ecma_transforms_macros::parallel;
 use swc_ecma_utils::{private_ident, UsageFinder};
 use swc_ecma_visit::{as_folder, noop_visit_mut_type, Fold, VisitMut, VisitMutWith};
 
@@ -28,7 +29,15 @@ pub fn function_name() -> impl 'static + Copy + Fold + VisitMut {
 #[derive(Clone, Copy)]
 struct FnName;
 
-struct Renamer {
+impl Parallel for FnName {
+    fn create(&self) -> Self {
+        *self
+    }
+
+    fn merge(&mut self, _: Self) {}
+}
+
+struct Rename {
     name: Option<Ident>,
 }
 
@@ -41,6 +50,7 @@ fn prepare(i: Ident) -> Ident {
     i
 }
 
+#[parallel]
 impl VisitMut for FnName {
     noop_visit_mut_type!();
 
@@ -52,7 +62,7 @@ impl VisitMut for FnName {
         }
 
         if let Some(ident) = expr.left.as_ident_mut() {
-            let mut folder = Renamer {
+            let mut folder = Rename {
                 name: Some(ident.clone()),
             };
 
@@ -86,7 +96,7 @@ impl VisitMut for FnName {
 
         match decl.name {
             Pat::Ident(ref mut ident) => {
-                let mut folder = Renamer {
+                let mut folder = Rename {
                     name: Some(prepare(ident.id.clone())),
                 };
                 decl.init.visit_mut_with(&mut folder);
@@ -131,7 +141,7 @@ macro_rules! noop {
     };
 }
 
-impl VisitMut for Renamer {
+impl VisitMut for Rename {
     noop_visit_mut_type!();
 
     impl_for!(visit_mut_fn_expr, FnExpr);
